/* Copyright (C) 2002, by Rupert Paget (rpaget@vision.ee.ethz.ch),
 * all rights reserved.
 *
 * This software is copyrighted as noted below. It may be freely copied,
 * modified, and redistributed, provided that the copyright notice is
 * preserved on all copies.
 *
 * There is no warranty or other guarantee of fitness for this software,
 * it is provided solely "as is". Bug reports or fixes may be sent
 * to the author, who may or may not act on them as he desires.
 *
 * You may not include this software in a commercial program or other
 * software product without the expressed permission of the copyright owner.
 *
 * If you modify this software, you should include a notice giving the
 * name of the person performing the modification, the date of modification,
 * and the reason for such modification.
 */

#ifndef _Option_h
#define _Option_h

#include <iostream>
#include <string>
#include <vector>
#include <stdio.h>
#include "Glib.h"

using namespace std;

#define LEVELS 256
#define NEIGH_ORDER 1
#define SQUARE false
#define TREE_MAX 6
#define CYCLIC false
#define ITERATIONS 1
#define WINDOW 0
#define KNEAREST 20

class Option {

 private:
    vector<const char *> inputFileV;     //input texture file
    vector<const char *> inputFileMaskV; //input mask file
    int inputFileVn;      //input texture file number
    int inputFileMaskVn;  //input mask file number
    string inputFile;     //input texture file
    string inputFileMask; //input mask file
    string outputFile;    //output texture file
    string outputFileMask;//output mask file (not operational yet)
    bool maskIn;
    bool maskOut;
    int levels;           //number of grey levels in the image
    int neighOrder;       //neighbourhood order ie size
    bool square;          //true for square neighbourhood
    int treeMax;          //quadtree height
    bool cyclic;          //true for ouput image to be cyclic
    int iterations;       //number of iterations over output image
    int window;           //window variable for Parzen density estimator
    int kNearest;         //k nearest neighbourhoods
    int rows;             //output rows
    int cols;             //output cols

 public:
    Option();
    Option(int theArgc, const char **theArgv);
    ~Option();

    string getInputFile() const {return inputFile;}
    string getInputFileMask() const {return inputFileMask;}
    string getOutputFile() const {return outputFile;}
    bool getMaskIn() const {return maskIn;}
    bool getMaskOut() const {return maskOut;}
    int getLevels() const {return levels;}
    int getNeighOrder() const {return neighOrder;}
    bool getSquare() const {return square;}
    int getTreeMax() const {return treeMax;}
    bool getCyclic() const {return cyclic;}
    int getIterations() const {return iterations;}
    int getWindow() const {return window;}
    int getKNearest() const {return kNearest;}
    int getRows() const {return rows;}
    int getCols() const {return cols;}

    void parseArgs(int theArgc, const char *theArgv[]);
    void setRows(int rowsOut);
    void setCols(int colsOut);
    void setTreeMax(int treeMaxIn);
    bool InputFile();
    bool OutputFile();

 private:
    void help(const char *progName);
};

#endif
